==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QCborParserError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcborvalue.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCborParserError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborParserError")
    QCborParserError *_ptr = reinterpret_cast<QCborParserError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCborParserError_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCborParserError *__qt_this = new(__qtjambi_ptr) QCborParserError();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCborParserError
void __qt_destruct_QCborParserError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborParserError")
    reinterpret_cast<QCborParserError*>(ptr)->~QCborParserError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCborParserError::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_initialize_1native__Lio_qt_core_QCborParserError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborParserError::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborParserError_0, sizeof(QCborParserError), typeid(QCborParserError), false, &deleter_QCborParserError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCborParserError::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborParserError::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCborParserError::operator==(QCborParserError,QCborParserError)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_operator_1equal_1native_1cref_1QCborParserError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborParserError::operator==(QCborParserError,QCborParserError)", __qt_this)
        const QCborParserError& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCborParserError>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_setError_1native_1cref_1QCborError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID error0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError& __qt_error0 = QtJambiAPI::valueReferenceFromNativeId<QCborError>(error0);
        __qt_this->error = __qt_error0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_error_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError&  __qt_value = __qt_this->error;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_setOffset_1native_1qint64__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<qint64>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint64  __qt_value = __qt_this->offset;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborParserError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCborParserError>("QCborParserError", "io/qt/core/QCborParserError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCborParserError, {
        ConstructorInfo(&__qt_construct_QCborParserError_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborParserError);
    registerMetaType<QCborParserError>("QCborParserError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QCborParserError_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcborvalue.h>
#include <QtCore/QVariant>
#include <QtCore/qcborcommon.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCborParserError(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCborParserError")
    QCborParserError *_ptr = reinterpret_cast<QCborParserError *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCborParserError()
void __qt_construct_QCborParserError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborParserError()")
    Q_UNUSED(__java_arguments)
    QCborParserError *__qt_this = new(__qtjambi_ptr) QCborParserError();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QCborParserError::QCborParserError()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_initialize_1native__Lio_qt_core_QCborParserError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborParserError::QCborParserError()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborParserError, sizeof(QCborParserError), typeid(QCborParserError), 0, false, &deleter_QCborParserError, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCborParserError(QCborParserError)
void __qt_construct_QCborParserError_cref_QCborParserError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborParserError(QCborParserError)")
    jobject other0 = __java_arguments[0].l;
    const QCborParserError& __qt_other0 = qtjambi_cast<const QCborParserError&>(__jni_env, other0);
    QCborParserError *__qt_this = new(__qtjambi_ptr) QCborParserError(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QCborParserError::QCborParserError(QCborParserError)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_initialize_1native__Lio_qt_core_QCborParserError_2Lio_qt_core_QCborParserError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborParserError::QCborParserError(QCborParserError)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborParserError_cref_QCborParserError, sizeof(QCborParserError), typeid(QCborParserError), 0, false, &deleter_QCborParserError, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCborParserError{qint64,QCborError}
void __qt_construct_QCborParserError_qint64_QCborError(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCborParserError{qint64,QCborError}")
    jlong offset0 = __java_arguments[0].j;
    Q_UNUSED(offset0)
    jobject error1 = __java_arguments[1].l;
    QCborError __qt_error1 = qtjambi_cast<QCborError>(__jni_env, error1);
    QCborParserError *__qt_this = new(__qtjambi_ptr) QCborParserError{static_cast<qint64>(offset0), __qt_error1};
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QCborParserError::QCborParserError{qint64,QCborError}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_initialize_1native__Lio_qt_core_QCborParserError_2JLio_qt_core_QCborError_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jlong offset0,
 jobject error1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCborParserError::QCborParserError{qint64,QCborError}")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].j = offset0;
        arguments[1].l = error1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCborParserError_qint64_QCborError, sizeof(QCborParserError), typeid(QCborParserError), 0, false, &deleter_QCborParserError, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCborParserError
void __qt_destruct_QCborParserError(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCborParserError")
    reinterpret_cast<QCborParserError*>(ptr)->~QCborParserError();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCborParserError::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborParserError::errorString()const", __this_nativeId)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCborParserError::operator==(QCborParserError,QCborParserError)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_equals_1native_1cref_1QCborParserError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCborParserError::operator==(QCborParserError,QCborParserError)", __this_nativeId)
        const QCborParserError& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QCborParserError>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_setError_1native_1cref_1QCborError__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID error0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError& __qt_error0 = QtJambiAPI::valueReferenceFromNativeId<QCborError>(error0);
        __qt_this->error = __qt_error0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_error_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCborError&  __qt_value = __qt_this->error;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_setOffset_1native_1qint64__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong offset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offset = static_cast<qint64>(offset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_offset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qint64  __qt_value = __qt_this->offset;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCborParserError_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCborParserError *__qt_this = QtJambiAPI::objectFromNativeId<QCborParserError>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCborParserError(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCborParserError>("QCborParserError", "io/qt/core/QCborParserError");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QCborParserError, {
        ConstructorInfo(&__qt_construct_QCborParserError, nullptr)
       ,ConstructorInfo(&__qt_construct_QCborParserError_cref_QCborParserError, "Lio/qt/core/QCborParserError;")
       ,ConstructorInfo(&__qt_construct_QCborParserError_qint64_QCborError, "JLio/qt/core/QCborError;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCborParserError);
    registerMetaType<QCborParserError>("QCborParserError");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
